                        KAVYANARTHAKI
// -------------------------------------------------------- //

The unique rhythmic structure of verse/poems in Malayalam are referred to as Malayalam meter or Vrutham. It is also referred to as Bhasha Vruthams, Maathra Vruthams, and Dravida Vrithams (the last two are  only approximate references).  Sanskrit meters have also been used in Malayalam language, but of late, they have not been very popular (When Sanskrit meters are used in Malayalam, they undergo a change, succumbing to the flexibility of Malayalam tradition). Also, meter-free poems (Muktha-Chandass) have gained an upperhand in current times.  A padyam(verse) or kavitha(poem) can be ‘read’, ‘recited’ or ‘sung’. In each of these performances, a poem may exhibit specific rhythmic patterns. Poetic meter is intimately related to such rhythmic patterns.  In Malayalam, the rhythmic pattern that manifests in the ‘recital’ or ‘singing’ of the poem, is reckoned as its meter (“Vritham”). Maveli, Tharangini, Nathonnatha, Annanada, Kakali, Keka, Omanakuttan etc are some of the famous Malayalam meters. To analyse meters of Malayalam poems, we need some basic computational analysis of verses. Kavyanarthaki package caters to some of such requirements and is an ongoing project at the University of Kerala India. 
